@@ -192,7 +192,7 @@ const char *parseversion(struct versionrevision *rversion, const char *string) {
     epoch= strtoul(string,&eepochcolon,10);
     if (colon != eepochcolon) return "epoch in version is not number";
     if (!*++colon) return "nothing after colon in version number";
-    string= colon+1;
+    string= colon;
     rversion->epoch= epoch;
   } else {
     rversion->epoch= 0;
