@@ -404,6 +404,12 @@ int tarobject(struct TarInfo *ti) {
     }
     if (fchown(fd,ti->UserID,ti->GroupID))
       ohshite("error setting ownership of `%.255s'",ti->Name);
+    /* We flush the stream here to avoid any future
+     * writes, which will mask any setuid or setgid
+     * attemps by fchmod below.
+     */
+    if (fflush(thefile) == EOF)
+      ohshite("error flushing `%.255s'",ti->Name);
     if (fchmod(fd,ti->Mode & ~S_IFMT))
       ohshite("error setting permissions of `%.255s'",ti->Name);
     pop_cleanup(ehflag_normaltidy); /* thefile= fdopen(fd) */
