@@ -464,6 +464,34 @@ void enqperpackage(const char *const *argv) {
   }
 }
 
+void assertepoch(const char *const *argv) {
+  static struct versionrevision epochversion = {~0UL,0,0};
+  struct pkginfo *pkg;
+
+  if (*argv) badusage("--assert-working-epoch does not take any arguments");
+
+  modstatdb_init(admindir,msdbrw_readonly);
+  pkg= findpackage("dpkg");
+  if (epochversion.epoch == ~0UL) {
+    epochversion.epoch= 0;
+    epochversion.version= nfstrsave("1.4.0.7");
+    epochversion.revision= 0;
+  }
+  switch (pkg->status) {
+  case stat_installed:
+    break;
+  case stat_unpacked: case stat_halfconfigured: case stat_halfinstalled:
+    if (versionsatisfied3(&pkg->configversion,&epochversion,dvr_laterequal))
+      break;
+    printf("Version of dpkg with working epoch support not yet configured.\n"
+           " Please use `dpkg --configure dpkg', and then try again.\n");
+    exit(1);
+  default:
+    printf("dpkg not recorded as installed, cannot check for epoch support !\n");
+    exit(1);
+  }
+}
+
 void assertpredep(const char *const *argv) {
   static struct versionrevision predepversion = {~0UL,0,0};
   struct pkginfo *pkg;
@@ -472,7 +500,7 @@ void assertpredep(const char *const *argv) {
 
   modstatdb_init(admindir,msdbrw_readonly);
   pkg= findpackage("dpkg");
-  if (!predepversion.epoch == ~0UL) {
+  if (predepversion.epoch == ~0UL) {
     predepversion.epoch= 0;
     predepversion.version= nfstrsave("1.1.0");
     predepversion.revision= 0;
