@@ -83,7 +83,8 @@ Usage: \n\
 Use " DPKG " -b|--build|-c|--contents|-e|--control|-I|--info|-f|--field|\n\
  -x|--extract|-X|--vextract|--fsys-tarfile  on archives (type " BACKEND " --help.)\n\
 \n\
-For internal use: " DPKG " --assert-support-predepends | --predep-package\n\
+For internal use: " DPKG " --assert-support-predepends | --predep-package |\n\
+  --assert-working-epoch\n\
 \n\
 Options:
   --admindir=<directory>     Use <directory> instead of " ADMINDIR "\n\
@@ -316,6 +317,7 @@ static const struct cmdinfo cmdinfos[]= {
   ACTION( "print-architecture",              0,  act_printarch,     printarch       ),
   ACTION( "print-gnu-build-architecture",    0,  act_printgnuarch,  printarch       ),
   ACTION( "assert-support-predepends",       0,  act_assertpredep,  assertpredep    ),
+  ACTION( "assert-working-epoch",            0,  act_assertepoch,   assertepoch     ),
   ACTION( "print-installation-architecture", 0,  act_printinstarch, printinstarch   ),
   ACTION( "predep-package",                  0,  act_predeppackage, predeppackage   ),
   ACTION( "compare-versions",                0,  act_cmpversions,   cmpversions     ),
