@@ -101,6 +101,8 @@ void process_archive(const char *filename) {
     pfilename= filename;
   }
 
+  if (stat(filename,&stab)) ohshite("cannot access archive");
+
   if (!f_noact) {
     /* We can't `tentatively-reassemble' packages. */
     if (!reasmbuf) {
@@ -167,6 +169,11 @@ void process_archive(const char *filename) {
 
   parsedb(cidir, pdb_recordavailable|pdb_rejectstatus|pdb_weakclassification,
           &pkg,0,0);
+  pkg->files= nfmalloc(sizeof(struct filedetails));
+  pkg->files->next= 0;
+  pkg->files->name= pkg->files->msdosname= pkg->files->md5sum= 0;
+  pkg->files->size= nfmalloc(30);
+  sprintf(pkg->files->size,"%lu",(unsigned long)stab.st_size);
 
   if (cipaction->arg == act_avail) {
     printf("Recorded info about %s from %s.\n",pkg->name,pfilename);
@@ -275,7 +282,10 @@ void process_archive(const char *filename) {
   filesdbinit();
   
   if (pkg->status != stat_notinstalled && pkg->status != stat_configfiles)
-    printf("Preparing to replace %s (using %s) ...\n",pkg->name,pfilename);
+    printf("Preparing to replace %s %s (using %s) ...\n",
+           pkg->name,
+           versiondescribe(&pkg->installed.version,vdew_nonambig),
+           pfilename);
   else
     printf("Unpacking %s (from %s) ...\n",pkg->name,pfilename);
 
@@ -744,6 +754,7 @@ void process_archive(const char *filename) {
   pkg->installed.maintainer= pkg->available.maintainer;
   pkg->installed.source= pkg->available.source;
   pkg->installed.architecture= 0; /* This is irrelevant in the status file. */
+  pkg->installed.installedsize= pkg->available.installedsize;
   pkg->installed.version= pkg->available.version;
 
   /* We have to generate our own conffiles structure. */
@@ -880,6 +891,7 @@ void process_archive(const char *filename) {
     otherpkg->installed.depends= 0;
     otherpkg->installed.essential= 0;
     otherpkg->installed.description= otherpkg->installed.maintainer= 0;
+    otherpkg->installed.installedsize= otherpkg->installed.source= 0;
     otherpkg->installed.conffiles= 0;
     blankversion(&otherpkg->installed.version);
     otherpkg->installed.arbs= 0;
