@@ -247,11 +247,11 @@ void removal_bulk(struct pkginfo *pkg) {
                 pkg->name, namenode->name);
         push_leftover(&leftover,namenode);
         continue;
-      } else if (errno == EPERM) {
+      } else if (errno == EBUSY || errno == EPERM) {
         fprintf(stderr, DPKG " - warning: while removing %.250s,"
                 " unable to remove directory `%.250s':"
-                " Operation not permitted - directory may be a mount point ?\n",
-                pkg->name, namenode->name);
+                " %s - directory may be a mount point ?\n",
+                pkg->name, namenode->name, strerror(errno));
         push_leftover(&leftover,namenode);
         continue;
       }
@@ -457,6 +457,7 @@ void removal_bulk(struct pkginfo *pkg) {
     pkg->installed.depends= 0;
     pkg->installed.essential= 0;
     pkg->installed.description= pkg->installed.maintainer= 0;
+    pkg->installed.source= pkg->installed.installedsize= 0;
     blankversion(&pkg->installed.version);
     pkg->installed.arbs= 0;
   }
