@@ -76,6 +76,8 @@ while (@ARGV) {
         $changelogformat=$1;
     } elsif (m/^-D([^\=:]+)[=:]/) {
         $override{$1}= $';
+    } elsif (m/^-u/) {
+        $uploadfilesdir= $';
     } elsif (m/^-U([^\=:]+)$/) {
         $remove{$1}= 1;
     } elsif (m/^-V(\w[-:0-9A-Za-z]*)[=:]/) {
@@ -201,9 +203,10 @@ if (!$binaryonly) {
     $pri= $sourcedefault{'Priority'};
     if (!length($pri)) { $pri='-'; &warn("missing Priority for source files"); }
 
-    $dsc= "$uploadfilesdir/${sourcepackage}_${version}.dsc";
+    ($sversion = $version) =~ s/^\d+://;
+    $dsc= "$uploadfilesdir/${sourcepackage}_${sversion}.dsc";
     open(CDATA,"< $dsc") || &error("cannot open .dsc file $dsc: $!");
-    push(@sourcefiles,"${sourcepackage}_${version}.dsc");
+    push(@sourcefiles,"${sourcepackage}_${sversion}.dsc");
     
     &parsecdata('S',-1,"source control file $dsc");
     $files= $fi{'S Files'};
