@@ -246,7 +246,7 @@ if ($opmode eq 'build') {
                   ".orig.tar.gz (wanted $basename.orig.tar.gz)");
     } else {
         $tardirbase= $dirbase; $tardirname= $dirname;
-        $tarname= "$basename.tar.gz";
+        $tarname= "$basenamerev.tar.gz";
     }
 
 #print STDERR ">$dir|$origdir|$origtargz|$sourcestyle<\n";
